@@ -1,11 +1,25 @@
 test_that("coin_history_ohlc returns correct results", {
+  skip_on_cran()
+  Sys.sleep(10)
+
   r <- coin_history_ohlc(
     coin_id = "cardano",
     vs_currency = "usd",
     days = 7L,
-    max_attempts = 1L
+    max_attempts = 3
   )
 
+  skip_if(is.null(r), "Data could not be retrieved")
+
+  r2 <- coin_history_ohlc(
+    coin_id = c("bitcoin", "polkadot", "tron"),
+    vs_currency = "usd",
+    days = 7L,
+    max_attempts = 3
+  )
+
+  skip_if(is.null(r2), "Data could not be retrieved")
+
   expect_named(r, c(
     "timestamp", "coin_id", "vs_currency", "price_open",
     "price_high", "price_low", "price_close"
@@ -19,4 +33,6 @@ test_that("coin_history_ohlc returns correct results", {
   expect_type(r$price_high, "double")
   expect_type(r$price_low, "double")
   expect_type(r$price_close, "double")
+
+  expect_setequal(unique(r2$coin_id), c("bitcoin", "polkadot", "tron"))
 })
