@@ -1,9 +1,12 @@
 test_that("exchange_rates returns correct results", {
-  r1 <- exchange_rate(currency = NULL, max_attempts = 1L)
-  r2 <- exchange_rate(
-    currency = c("usd", "eur", "gbp"),
-    max_attempts = 1L
-  )
+  skip_on_cran()
+  Sys.sleep(30)
+
+  r1 <- exchange_rate(currency = NULL)
+  r2 <- exchange_rate(currency = c("usd", "eur", "gbp"))
+
+  skip_if(is.null(r1), "Data could not be retrieved")
+  skip_if(is.null(r2), "Data could not be retrieved")
 
   expect_s3_class(r1, "tbl")
   expect_s3_class(r2, "tbl")
