@@ -1,7 +1,11 @@
 test_that("supported_coins returns correct objects", {
-  r <- supported_coins(max_attempts = 2L)
+  skip_on_cran()
+  Sys.sleep(30)
 
-  Sys.sleep(1)
+  r <- supported_coins()
+  skip_if(is.null(r), "Data could not be retrieved")
+
+  Sys.sleep(2)
 
   expect_s3_class(r, "tbl")
   expect_named(r, c("coin_id", "symbol", "name"))
