@@ -1,7 +1,11 @@
 test_that("supported_currencies returns correct results", {
-  r <- supported_currencies(max_attempts = 1)
+  skip_on_cran()
+  Sys.sleep(30)
 
-  Sys.sleep(1)
+  r <- supported_currencies()
+  skip_if(is.null(r), "Data could not be retrieved")
+
+  Sys.sleep(12)
 
   expect_type(r, "character")
   expect_true(is.vector(r))
